==> prestashop_1.4.0.2.zip: prestashop/modules/cashticket/es.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{cashticket}prestashop>cashticket-accept-payment_330bf06fb43e715e5d03c9fd016df4cd'] = 'El pago aún no ha sido aceptado';
$_MODULE['<{cashticket}prestashop>cashticket-accept-payment_486cb12e1ec3c8b28b80a8eb9f2db2c0'] = 'Aceptar el pago';
$_MODULE['<{cashticket}prestashop>cashticket-accept-payment_e9b3579d8e877bcd29ab436f2ef87cc8'] = 'Rechazar el pago';
$_MODULE['<{cashticket}prestashop>cashticket-confirmation_2e2117b7c81aa9ea6931641ea2c6499f'] = 'Su pedido en';
$_MODULE['<{cashticket}prestashop>cashticket-confirmation_75fbf512d744977d62599cc3f0ae2bb4'] = 'ha sido registrado.';
$_MODULE['<{cashticket}prestashop>cashticket-confirmation_91675397c13245179e4bc959514fc2ca'] = 'Ha elegido pagar con';
$_MODULE['<{cashticket}prestashop>cashticket-confirmation_2c987f462c2ab7fc63e061e871e6a97d'] = 'modo';
$_MODULE['<{cashticket}prestashop>cashticket-confirmation_e6dc7945b557a1cd949bea92dd58963e'] = 'Le enviaremos su pedido rápidamente';
$_MODULE['<{cashticket}prestashop>cashticket-confirmation_0db71da7150c27142eef9d22b843b4a9'] = 'Para cualquier pregunta, póngase en contacto con ';
$_MODULE['<{cashticket}prestashop>cashticket-confirmation_64430ad2835be8ad60c59e7d44e4b0b1'] = 'el servicio clientela';
$_MODULE['<{cashticket}prestashop>cashticket_4512bbd48918c03027387a6c8e911342'] = 'CashTicket';
$_MODULE['<{cashticket}prestashop>cashticket_21d3d890383dc93343ce57c221ce5b3d'] = 'Aceptar los pagos a través de CashTicket';
$_MODULE['<{cashticket}prestashop>cashticket_bed51f5187d4bf98e08f44d93f3098d9'] = 'Disposición creada. En espera del débito';
$_MODULE['<{cashticket}prestashop>cashticket_894f0316a71ef67255369c82bf8a0e5b'] = 'El estado de la disposición no es válido:';
$_MODULE['<{cashticket}prestashop>cashticket_e79174d4c28918ea3743a8386092cfab'] = 'Se ha producido un error durante el pago:';
$_MODULE['<{cashticket}prestashop>cashticket_36ec50c0e914dd2fb48a1b27540512ce'] = 'Pago aceptado.';
$_MODULE['<{cashticket}prestashop>cashticket_d6ca44369efe062cec0c09f392465f55'] = 'Este módulo requiere la librería PHP cURL para funcionar correctamente.';
$_MODULE['<{cashticket}prestashop>cashticket_fe9da2c5e2e153d2415b4cd5d91166a4'] = 'No tiene derechos de escritura.';
$_MODULE['<{cashticket}prestashop>cashticket_139cfa047b503ac5b9a6b4b1b03090ad'] = 'Para funcionar correctamente, este módulo necesita la divisa:';
$_MODULE['<{cashticket}prestashop>cashticket_ef5d34b04ab3b2eaaf7cb9d0f51267ed'] = 'Configurar cada divisa independientemente:';
$_MODULE['<{cashticket}prestashop>cashticket_f7e5c041093ae6902476457802835a1f'] = '(El módulo de pago no se mostrará a los clientes que utilicen una divisa no configurada)';
$_MODULE['<{cashticket}prestashop>cashticket_7d3d009ac1b9d1e826a1a72c046ea635'] = 'Configuración en';
$_MODULE['<{cashticket}prestashop>cashticket_229a7ec501323b94db7ff3157a7623c9'] = 'ID vendedor';
$_MODULE['<{cashticket}prestashop>cashticket_845314022daaa8b665e718c4b51738aa'] = 'Certificado Keyring';
$_MODULE['<{cashticket}prestashop>cashticket_a01813de717585e9ac9458bbfc54485a'] = 'Keyring PW';
$_MODULE['<{cashticket}prestashop>cashticket_254f642527b45bc260048e30704edb39'] = 'Configuración';
$_MODULE['<{cashticket}prestashop>cashticket_0ba29c6a1afacf586b03a26162c72274'] = 'Entorno';
$_MODULE['<{cashticket}prestashop>cashticket_1d5ad3d37f236c9eebda547690373bba'] = 'Tipo de negocio';
$_MODULE['<{cashticket}prestashop>cashticket_9eacfa0a89b48392a962b3fed24cd58e'] = 'Pago inmediato';
$_MODULE['<{cashticket}prestashop>cashticket_c80a51a60c5ee43553c3881459b8f431'] = 'Actualizar la configuración';
$_MODULE['<{cashticket}prestashop>cashticket_1ed8d28fc462cdaba8f2ce9a400f2bfa'] = 'Debe dar un certificado para el ID del vendedor';
$_MODULE['<{cashticket}prestashop>cashticket_bbced877c13c763f0141ff906c8ed0e5'] = 'Archivo no válido';
$_MODULE['<{cashticket}prestashop>cashticket_97e5793f511c7930ab295997cb28553a'] = 'ID vendedor no válida';
$_MODULE['<{cashticket}prestashop>cashticket_c888438d14855d7d96a2724ee9c306bd'] = 'Configuración actualizada';
$_MODULE['<{cashticket}prestashop>cashticket_d139abab2541129dfae24c733635104c'] = 'El archivo no se ha cargado correctamente';
$_MODULE['<{cashticket}prestashop>cashticket_d2bbf245e9591814fe994df3cae95964'] = 'El archivo está vacío';
$_MODULE['<{cashticket}prestashop>cashticket_ebbe99d835c79ead89db1b2b9e4fe70f'] = 'La transacción no ha podido inicializarse debido a problemas de conexión. Si el problema persiste, contáctenos.';
$_MODULE['<{cashticket}prestashop>cashticket_99f6765a05b697eb78e8c2e5e228f2fc'] = 'Disposición consumida';
$_MODULE['<{cashticket}prestashop>cashticket_c3e260f43a99b6fd907538953fe700d0'] = 'Disposición abandonada';
$_MODULE['<{cashticket}prestashop>cashticket_022492bc69b8205957d53b4166cd7090'] = 'Se ha producido un error en el momento de abandonar.';
$_MODULE['<{cashticket}prestashop>cashticket_12f989194ad92e23c0eb3941db7f6720'] = 'Acepte los pagos con prepago en su tienda en línea. Cash-Ticket es un método de pago seguro y sencillo para Internet. Cash-Ticket permite pagos sin tarjeta de crédito ni datos bancarios personales. Lo único que se necesita para pagar en una tienda en línea es un código PIN de 16 cifras. Así, los consumidores pueden realizar pagos en línea sin tarjeta de crédito ni cuenta bancaria. ';
$_MODULE['<{cashticket}prestashop>cashticket_75f5c89352ca1b7efc6bb03899ab9224'] = 'Se ha producido un error. Consulte el apartado \"Mensajes\" para más información.';
$_MODULE['<{cashticket}prestashop>cashticket_a9ced76f2dd6907220fa95b3a136b04a'] = 'Importe incorrecto';
$_MODULE['<{cashticket}prestashop>disposition-error_393988def796f78c4b673b90548f3afa'] = 'La disposición se encuentra en un estado no válido';
$_MODULE['<{cashticket}prestashop>disposition-error_5db89f2bf67f2c7dbd86cac101c3c1b8'] = 'No tiene autorización para recuperar el pago.';
$_MODULE['<{cashticket}prestashop>payment_da9c72b9e543135f3f59e3c8ac68ef35'] = 'Pagar con';

==> prestashop_1.4.0.7.zip: prestashop/modules/cashticket/es.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{cashticket}prestashop>cashticket-accept-payment_330bf06fb43e715e5d03c9fd016df4cd'] = 'El pago aún no ha sido aceptado';
$_MODULE['<{cashticket}prestashop>cashticket-accept-payment_486cb12e1ec3c8b28b80a8eb9f2db2c0'] = 'Aceptar el pago';
$_MODULE['<{cashticket}prestashop>cashticket-accept-payment_e9b3579d8e877bcd29ab436f2ef87cc8'] = 'Rechazar el pago';
$_MODULE['<{cashticket}prestashop>cashticket-confirmation_2e2117b7c81aa9ea6931641ea2c6499f'] = 'Su pedido en';
$_MODULE['<{cashticket}prestashop>cashticket-confirmation_75fbf512d744977d62599cc3f0ae2bb4'] = 'ha sido registrado.';
$_MODULE['<{cashticket}prestashop>cashticket-confirmation_91675397c13245179e4bc959514fc2ca'] = 'Ha elegido pagar con';
$_MODULE['<{cashticket}prestashop>cashticket-confirmation_2c987f462c2ab7fc63e061e871e6a97d'] = 'modo';
$_MODULE['<{cashticket}prestashop>cashticket-confirmation_e6dc7945b557a1cd949bea92dd58963e'] = 'Le enviaremos su pedido rápidamente';
$_MODULE['<{cashticket}prestashop>cashticket-confirmation_0db71da7150c27142eef9d22b843b4a9'] = 'Para cualquier pregunta, póngase en contacto con ';
$_MODULE['<{cashticket}prestashop>cashticket-confirmation_64430ad2835be8ad60c59e7d44e4b0b1'] = 'el servicio clientela';
$_MODULE['<{cashticket}prestashop>cashticket_4512bbd48918c03027387a6c8e911342'] = 'CashTicket';
$_MODULE['<{cashticket}prestashop>cashticket_21d3d890383dc93343ce57c221ce5b3d'] = 'Aceptar los pagos a través de CashTicket';
$_MODULE['<{cashticket}prestashop>cashticket_bed51f5187d4bf98e08f44d93f3098d9'] = 'Disposición creada. En espera del débito';
$_MODULE['<{cashticket}prestashop>cashticket_894f0316a71ef67255369c82bf8a0e5b'] = 'El estado de la disposición no es válido:';
$_MODULE['<{cashticket}prestashop>cashticket_c1c25198721552ea8ddd963c7278d4ab'] = 'Se ha producido un error durante el pago:';
$_MODULE['<{cashticket}prestashop>cashticket_36ec50c0e914dd2fb48a1b27540512ce'] = 'Pago aceptado.';
$_MODULE['<{cashticket}prestashop>cashticket_d6ca44369efe062cec0c09f392465f55'] = 'Este módulo requiere la librería PHP cURL para funcionar correctamente.';
$_MODULE['<{cashticket}prestashop>cashticket_fe9da2c5e2e153d2415b4cd5d91166a4'] = 'No tiene derechos de escritura.';
$_MODULE['<{cashticket}prestashop>cashticket_139cfa047b503ac5b9a6b4b1b03090ad'] = 'Para funcionar correctamente, este módulo necesita la divisa:';
$_MODULE['<{cashticket}prestashop>cashticket_ef5d34b04ab3b2eaaf7cb9d0f51267ed'] = 'Configurar cada divisa independientemente:';
$_MODULE['<{cashticket}prestashop>cashticket_f7e5c041093ae6902476457802835a1f'] = '(El módulo de pago no se mostrará a los clientes que utilicen una divisa no configurada)';
$_MODULE['<{cashticket}prestashop>cashticket_7d3d009ac1b9d1e826a1a72c046ea635'] = 'Configuración en';
$_MODULE['<{cashticket}prestashop>cashticket_229a7ec501323b94db7ff3157a7623c9'] = 'ID vendedor';
$_MODULE['<{cashticket}prestashop>cashticket_845314022daaa8b665e718c4b51738aa'] = 'Certificado Keyring';
$_MODULE['<{cashticket}prestashop>cashticket_a01813de717585e9ac9458bbfc54485a'] = 'Keyring PW';
$_MODULE['<{cashticket}prestashop>cashticket_254f642527b45bc260048e30704edb39'] = 'Configuración';
$_MODULE['<{cashticket}prestashop>cashticket_0ba29c6a1afacf586b03a26162c72274'] = 'Entorno';
$_MODULE['<{cashticket}prestashop>cashticket_1d5ad3d37f236c9eebda547690373bba'] = 'Tipo de negocio';
$_MODULE['<{cashticket}prestashop>cashticket_b024248d9fecf8c34f629e89a9fb93b4'] = 'Pago inmediato';
$_MODULE['<{cashticket}prestashop>cashticket_c80a51a60c5ee43553c3881459b8f431'] = 'Actualizar la configuración';
$_MODULE['<{cashticket}prestashop>cashticket_1ed8d28fc462cdaba8f2ce9a400f2bfa'] = 'Debe dar un certificado para el ID del vendedor';
$_MODULE['<{cashticket}prestashop>cashticket_bbced877c13c763f0141ff906c8ed0e5'] = 'Archivo no válido';
$_MODULE['<{cashticket}prestashop>cashticket_97e5793f511c7930ab295997cb28553a'] = 'ID vendedor no válida';
$_MODULE['<{cashticket}prestashop>cashticket_c888438d14855d7d96a2724ee9c306bd'] = 'Configuración actualizada';
$_MODULE['<{cashticket}prestashop>cashticket_d139abab2541129dfae24c733635104c'] = 'El archivo no se ha cargado correctamente';
$_MODULE['<{cashticket}prestashop>cashticket_d2bbf245e9591814fe994df3cae95964'] = 'El archivo está vacío';
$_MODULE['<{cashticket}prestashop>cashticket_ebbe99d835c79ead89db1b2b9e4fe70f'] = 'La transacción no ha podido inicializarse debido a problemas de conexión. Si el problema persiste, contáctenos.';
$_MODULE['<{cashticket}prestashop>cashticket_99f6765a05b697eb78e8c2e5e228f2fc'] = 'Disposición consumida';
$_MODULE['<{cashticket}prestashop>cashticket_c3e260f43a99b6fd907538953fe700d0'] = 'Disposición abandonada';
$_MODULE['<{cashticket}prestashop>cashticket_f6a62a622cbba2c1b8cd0be062deff96'] = 'Se ha producido un error en el momento de abandonar.';
$_MODULE['<{cashticket}prestashop>cashticket_12f989194ad92e23c0eb3941db7f6720'] = 'Acepte los pagos con prepago en su tienda en línea. Cash-Ticket es un método de pago seguro y sencillo para Internet. Cash-Ticket permite pagos sin tarjeta de crédito ni datos bancarios personales. Lo único que se necesita para pagar en una tienda en línea es un código PIN de 16 cifras. Así, los consumidores pueden realizar pagos en línea sin tarjeta de crédito ni cuenta bancaria. ';
$_MODULE['<{cashticket}prestashop>cashticket_d59048f21fd887ad520398ce677be586'] = 'Más información';
$_MODULE['<{cashticket}prestashop>cashticket_ee363d108ef0c9c5a599d3afe04b9e32'] = 'Se ha producido un error. Consulte el apartado \"Mensajes\" para más información';
$_MODULE['<{cashticket}prestashop>cashticket_a9ced76f2dd6907220fa95b3a136b04a'] = 'Importe incorrecto';
$_MODULE['<{cashticket}prestashop>disposition-error_393988def796f78c4b673b90548f3afa'] = 'La disposición se encuentra en un estado no válido';
$_MODULE['<{cashticket}prestashop>disposition-error_5db89f2bf67f2c7dbd86cac101c3c1b8'] = 'No tiene autorización para recuperar el pago.';
$_MODULE['<{cashticket}prestashop>payment_da9c72b9e543135f3f59e3c8ac68ef35'] = 'Pagar con';
